.. image:: ../../_static/CSAwesomeLogo.png
    :width: 350
    :align: center


Stories
:::::::::::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   challengesInComputing.rst
   intervieweeIndex.rst